@@ -14,10 +14,7 @@ import constructs._jsii
 import ros_cdk_core._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@alicloud/ros-cdk-kafka",
-    "1.0.14",
-    __name__[0:-6],
-    "ros-cdk-kafka@1.0.14.jsii.tgz",
+    "@alicloud/ros-cdk-kafka", "1.3.0", __name__[0:-6], "ros-cdk-kafka@1.3.0.jsii.tgz"
 )
 
 __all__ = [
